
class TooManyRequests(Exception):
    pass


class InternalServerError(Exception):
    pass


class UnexpectedError(Exception):
    pass


class RuntimeNotFound(Exception):
    pass


class InvalidLanguage(Exception):
    pass


class InvalidArgumentType(Exception):
    pass
